using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using System;

[RequireComponent(typeof(Animator))]
[RequireComponent(typeof(StepBackScript))]
[RequireComponent(typeof(CrossOverScript))]
[RequireComponent(typeof(BehindBackScript))]
[RequireComponent(typeof(MovementScript))]
[RequireComponent(typeof(RoubarBolaScript))]
public class PlayerController : Controller
{
    // Use this for initialization
    void Start ()
    {
        inputs = new Inputs();
        //fazer dinamico
        setup();
        canMove = true;
        canSkill = true;
        myTurn = true;
        currentHand = 1;        
        changeTurn();
    }

    private void setup()
    {
        controlType = new KeyBoardControl();
        animatorController = GetComponent<Animator>();
    }

    private void Update()
    {
        inputs.behindBack = Input.GetAxisRaw(controlType.getBehindBackInput());
        inputs.crossOver = Input.GetAxisRaw(controlType.getCrossOverInput());
        inputs.stepBack = Input.GetAxisRaw(controlType.getStepBackInput());
        inputs.horizontalMovement = Input.GetAxisRaw(controlType.getHorizontalInput());
        inputs.verticalMovement = Input.GetAxisRaw(controlType.getVerticalInput());
        inputs.steal = Input.GetAxisRaw(controlType.getStealInput());
        inputs.block = Input.GetAxisRaw(controlType.getBlockInput());
    }

    public override void changeTurn()
    {
        if (myTurn)
        {
            GetComponent<StepBackScript>().enabled = true;
            GetComponent<CrossOverScript>().enabled = true;
            GetComponent<BehindBackScript>().enabled = true;
            GetComponent<MovementScript>().enabled = true;
            FindObjectOfType<ForceBarController>().enabled = true;
            animatorController.SetTrigger("AtkTurn");
            myTurn = false;
        }
        else
        {
            GetComponent<RoubarBolaScript>().enabled = true;
            GetComponent<MovementScript>().enabled = true;
            animatorController.SetTrigger("DefTurn");
            myTurn = true;
        }
        //do something
    }

    public virtual void OnDisable()
    {
        GetComponent<StepBackScript>().enabled = false;
        GetComponent<CrossOverScript>().enabled = false;
        GetComponent<BehindBackScript>().enabled = false;
        GetComponent<RoubarBolaScript>().enabled = false;
        GetComponent<MovementScript>().enabled = false;
        
        ForceBarController fbc = FindObjectOfType<ForceBarController>();
        if (fbc != null)
        {
            fbc.enabled = false;
        }
        animatorController.SetTrigger("Idle");
    }

    public void moveToPosition(Transform atkPosition, Transform defPosition)
    {
        if (myTurn)
        {
            GetComponent<MovementScript>().moveToPosition(atkPosition);
        }
        else
        {
            GetComponent<MovementScript>().moveToPosition(defPosition);
        }
    }
}
